- [https://github.com/jochym/abinitio-workshop](https://github.com/jochym/abinitio-workshop)
- by [yqshao](https://github.com/yqshao)
![](https://cloud.githubusercontent.com/assets/22888066/21761120/e47e2988-d68b-11e6-9e11-a894d7833d50.png)
